Documentation
¶
Overview ¶
Package run implements the `kontext start` orchestrator.
Index ¶
- func GenerateLocalSettings(sessionDir, kontextBinary, agentName, socketPath, mode string) (string, error)
- func GenerateSettings(sessionDir, kontextBinary, agentName string) (string, error)
- func Start(ctx context.Context, opts Options) error
- func StartLocal(ctx context.Context, opts Options) error
- func StartManaged(ctx context.Context, opts Options) error
- func VerifyBlockingHookSettings(settingsPath, kontextBinary, agentName string) error
- type AgentExitError
- type Options
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateLocalSettings ¶ added in v0.7.0
func GenerateLocalSettings(sessionDir, kontextBinary, agentName, socketPath, mode string) (string, error)
GenerateLocalSettings creates a Claude Code settings.json that connects hooks to the wrapper-owned local runtime socket.
func GenerateSettings ¶
GenerateSettings creates a Claude Code settings.json with Kontext hooks and returns the path to the generated file.
func StartLocal ¶ added in v0.7.0
StartLocal launches an agent with a wrapper-owned local runtime.
func StartManaged ¶ added in v0.7.0
StartManaged launches an agent with a hosted managed Kontext session.
func VerifyBlockingHookSettings ¶ added in v0.6.0
Types ¶
type AgentExitError ¶ added in v0.4.0
AgentExitError reports an agent process that launched but exited unsuccessfully.
func (*AgentExitError) Error ¶ added in v0.4.0
func (e *AgentExitError) Error() string
func (*AgentExitError) ExitCode ¶ added in v0.4.0
func (e *AgentExitError) ExitCode() int
func (*AgentExitError) Unwrap ¶ added in v0.4.0
func (e *AgentExitError) Unwrap() error
Click to show internal directories.
Click to hide internal directories.